==> apigateway-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/HttpIntegrationProps.java <==
package software.amazon.awscdk.services.apigateway;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:27:21.922Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface HttpIntegrationProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * HTTP method to use when invoking the backend URL.
     * 
     * Default: GET
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getHttpMethod();

    /**
     * Integration options, such as request/resopnse mapping, content handling, etc.
     * 
     * Default: defaults based on `IntegrationOptions` defaults
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.services.apigateway.IntegrationOptions getOptions();

    /**
     * Determines whether to use proxy integration or custom integration.
     * 
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.Boolean getProxy();

    /**
     * @return a {@link Builder} of {@link HttpIntegrationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link HttpIntegrationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private java.lang.String httpMethod;
        private software.amazon.awscdk.services.apigateway.IntegrationOptions options;
        private java.lang.Boolean proxy;

        /**
         * Sets the value of HttpMethod
         * @param httpMethod HTTP method to use when invoking the backend URL.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder httpMethod(java.lang.String httpMethod) {
            this.httpMethod = httpMethod;
            return this;
        }

        /**
         * Sets the value of Options
         * @param options Integration options, such as request/resopnse mapping, content handling, etc.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder options(software.amazon.awscdk.services.apigateway.IntegrationOptions options) {
            this.options = options;
            return this;
        }

        /**
         * Sets the value of Proxy
         * @param proxy Determines whether to use proxy integration or custom integration.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder proxy(java.lang.Boolean proxy) {
            this.proxy = proxy;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link HttpIntegrationProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public HttpIntegrationProps build() {
            return new Jsii$Proxy(httpMethod, options, proxy);
        }
    }

    /**
     * An implementation for {@link HttpIntegrationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements HttpIntegrationProps {
        private final java.lang.String httpMethod;
        private final software.amazon.awscdk.services.apigateway.IntegrationOptions options;
        private final java.lang.Boolean proxy;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.httpMethod = this.jsiiGet("httpMethod", java.lang.String.class);
            this.options = this.jsiiGet("options", software.amazon.awscdk.services.apigateway.IntegrationOptions.class);
            this.proxy = this.jsiiGet("proxy", java.lang.Boolean.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.String httpMethod, software.amazon.awscdk.services.apigateway.IntegrationOptions options, java.lang.Boolean proxy) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.httpMethod = httpMethod;
            this.options = options;
            this.proxy = proxy;
        }

        @Override
        public java.lang.String getHttpMethod() {
            return this.httpMethod;
        }

        @Override
        public software.amazon.awscdk.services.apigateway.IntegrationOptions getOptions() {
            return this.options;
        }

        @Override
        public java.lang.Boolean getProxy() {
            return this.proxy;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            if (this.getHttpMethod() != null) {
                obj.set("httpMethod", om.valueToTree(this.getHttpMethod()));
            }
            if (this.getOptions() != null) {
                obj.set("options", om.valueToTree(this.getOptions()));
            }
            if (this.getProxy() != null) {
                obj.set("proxy", om.valueToTree(this.getProxy()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            HttpIntegrationProps.Jsii$Proxy that = (HttpIntegrationProps.Jsii$Proxy) o;

            if (this.httpMethod != null ? !this.httpMethod.equals(that.httpMethod) : that.httpMethod != null) return false;
            if (this.options != null ? !this.options.equals(that.options) : that.options != null) return false;
            return this.proxy != null ? this.proxy.equals(that.proxy) : that.proxy == null;
        }

        @Override
        public int hashCode() {
            int result = this.httpMethod != null ? this.httpMethod.hashCode() : 0;
            result = 31 * result + (this.options != null ? this.options.hashCode() : 0);
            result = 31 * result + (this.proxy != null ? this.proxy.hashCode() : 0);
            return result;
        }
    }
}

==> apigateway-1.16.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/HttpIntegrationProps.java <==
package software.amazon.awscdk.services.apigateway;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.2 (build faba0be)", date = "2019-11-11T17:17:51.591Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.HttpIntegrationProps")
@software.amazon.jsii.Jsii.Proxy(HttpIntegrationProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface HttpIntegrationProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * HTTP method to use when invoking the backend URL.
     * 
     * Default: GET
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default java.lang.String getHttpMethod() {
        return null;
    }

    /**
     * Integration options, such as request/resopnse mapping, content handling, etc.
     * 
     * Default: defaults based on `IntegrationOptions` defaults
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default software.amazon.awscdk.services.apigateway.IntegrationOptions getOptions() {
        return null;
    }

    /**
     * Determines whether to use proxy integration or custom integration.
     * 
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default java.lang.Boolean getProxy() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link HttpIntegrationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link HttpIntegrationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private java.lang.String httpMethod;
        private software.amazon.awscdk.services.apigateway.IntegrationOptions options;
        private java.lang.Boolean proxy;

        /**
         * Sets the value of HttpMethod
         * @param httpMethod HTTP method to use when invoking the backend URL.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder httpMethod(java.lang.String httpMethod) {
            this.httpMethod = httpMethod;
            return this;
        }

        /**
         * Sets the value of Options
         * @param options Integration options, such as request/resopnse mapping, content handling, etc.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder options(software.amazon.awscdk.services.apigateway.IntegrationOptions options) {
            this.options = options;
            return this;
        }

        /**
         * Sets the value of Proxy
         * @param proxy Determines whether to use proxy integration or custom integration.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder proxy(java.lang.Boolean proxy) {
            this.proxy = proxy;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link HttpIntegrationProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public HttpIntegrationProps build() {
            return new Jsii$Proxy(httpMethod, options, proxy);
        }
    }

    /**
     * An implementation for {@link HttpIntegrationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements HttpIntegrationProps {
        private final java.lang.String httpMethod;
        private final software.amazon.awscdk.services.apigateway.IntegrationOptions options;
        private final java.lang.Boolean proxy;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.httpMethod = this.jsiiGet("httpMethod", java.lang.String.class);
            this.options = this.jsiiGet("options", software.amazon.awscdk.services.apigateway.IntegrationOptions.class);
            this.proxy = this.jsiiGet("proxy", java.lang.Boolean.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String httpMethod, final software.amazon.awscdk.services.apigateway.IntegrationOptions options, final java.lang.Boolean proxy) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.httpMethod = httpMethod;
            this.options = options;
            this.proxy = proxy;
        }

        @Override
        public java.lang.String getHttpMethod() {
            return this.httpMethod;
        }

        @Override
        public software.amazon.awscdk.services.apigateway.IntegrationOptions getOptions() {
            return this.options;
        }

        @Override
        public java.lang.Boolean getProxy() {
            return this.proxy;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getHttpMethod() != null) {
                data.set("httpMethod", om.valueToTree(this.getHttpMethod()));
            }
            if (this.getOptions() != null) {
                data.set("options", om.valueToTree(this.getOptions()));
            }
            if (this.getProxy() != null) {
                data.set("proxy", om.valueToTree(this.getProxy()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-apigateway.HttpIntegrationProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            HttpIntegrationProps.Jsii$Proxy that = (HttpIntegrationProps.Jsii$Proxy) o;

            if (this.httpMethod != null ? !this.httpMethod.equals(that.httpMethod) : that.httpMethod != null) return false;
            if (this.options != null ? !this.options.equals(that.options) : that.options != null) return false;
            return this.proxy != null ? this.proxy.equals(that.proxy) : that.proxy == null;
        }

        @Override
        public int hashCode() {
            int result = this.httpMethod != null ? this.httpMethod.hashCode() : 0;
            result = 31 * result + (this.options != null ? this.options.hashCode() : 0);
            result = 31 * result + (this.proxy != null ? this.proxy.hashCode() : 0);
            return result;
        }
    }
}
